==> plplot_5.10.0.orig.tar.gz: plplot-5.10.0/doc/doxygen/html/search/functions_72.js <==
var searchData=
[
  ['randd',['randd',['../classplstream.html#a548b5563e4a23301ca3ea443669d265e',1,'plstream::randd()'],['../classplplot_1_1core_1_1PLStream.html#af99be78ac0c125a40919934c4454316e',1,'plplot.core.PLStream.randd()']]],
  ['rd_5fcommand',['rd_command',['../plbuf_8c.html#afe25464ef6eee65400e6cc414e1a8bef',1,'plbuf.c']]],
  ['rd_5fdata',['rd_data',['../plbuf_8c.html#a242010916ecbf0311b25cb53dd279131',1,'plbuf.c']]],
  ['rdbuf_5fbop',['rdbuf_bop',['../plbuf_8c.html#aad64e647b7f7b3af09f3c62842c4f7c8',1,'plbuf.c']]],
  ['rdbuf_5feop',['rdbuf_eop',['../plbuf_8c.html#a209868297bfb200c84cbfe90ba08f0e0',1,'rdbuf_eop(PLStream *pls):&#160;plbuf.c'],['../plbuf_8c.html#ad7ca15074bcfb34b7be34e84f2ef4c9a',1,'rdbuf_eop(PLStream *PL_UNUSED(pls)):&#160;plbuf.c']]],
  ['rdbuf_5fesc',['rdbuf_esc',['../plbuf_8c.html#ae88980d2f7d522656c5950ddd56196dd',1,'plbuf.c']]],
  ['rdbuf_5ffill',['rdbuf_fill',['../plbuf_8c.html#aad07e02f2e79a2c170853e8aa4e6b2f9',1,'plbuf.c']]],
  ['rdbuf_5fimage',['rdbuf_image',['../plbuf_8c.html#aea9f032aa713660a5dc4c9977eaa61dd',1,'plbuf.c']]],
  ['rdbuf_5finit',['rdbuf_init',['../plbuf_8c.html#a8db7bde63185bde9dc11e067032d72ca',1,'rdbuf_init(PLStream *pls):&#160;plbuf.c'],['../plbuf_8c.html#ada55e60d5d9707c8b9422473cb15b370',1,'rdbuf_init(PLStream *PL_UNUSED(pls)):&#160;plbuf.c']]],
  ['rdbuf_5fline',['rdbuf_line',['../plbuf_8c.html#a7bec22c9791616b92153645c10edbc36',1,'plbuf.c']]],
  ['rdbuf_5fpolyline',['rdbuf_polyline',['../plbuf_8c.html#a5cc6b30bbe75730cde65b3a2ba00b084',1,'plbuf.c']]],
  ['rdbuf_5fstate',['rdbuf_state',['../plbuf_8c.html#ad9ba8fe84be30902c7d521c076a91456',1,'plbuf.c']]],
  ['rdbuf_5fswin',['rdbuf_swin',['../plbuf_8c.html#a2bc6f17b2d907b6785d6c898b45bb064',1,'plbuf.c']]],
  ['rdbuf_5ftext',['rdbuf_text',['../plbuf_8c.html#afa641052a2e12eb594108a56d6eaa710',1,'plbuf.c']]],
  ['rdbuf_5ftext_5funicode',['rdbuf_text_unicode',['../plbuf_8c.html#a6e3e586984481314f86de46295eea6f7',1,'plbuf.c']]],
  ['read_5fdouble_5fmatrix',['read_double_Matrix',['../plplotluacLUA__wrap_8c.html#a03fbc9a75a0be1fa43da9accc215aab2',1,'plplotluacLUA_wrap.c']]],
  ['read_5fline',['read_line',['../plctrl_8c.html#a5e4545bc3f40c3e8ad92cdb1ae7e7d46',1,'plctrl.c']]],
  ['readdata',['ReadData',['../plframe_8c.html#aa66a237bb52c6ba116dc6f27cf390fcf',1,'ReadData(ClientData, int):&#160;plframe.c'],['../plplotter_8c.html#aa66a237bb52c6ba116dc6f27cf390fcf',1,'ReadData(ClientData, int):&#160;plplotter.c']]],
  ['readdir',['readdir',['../dirent__msvc_8h.html#aff48ec2514bda89769c968c66db181f3',1,'dirent_msvc.h']]],
  ['realloc_5fline',['realloc_line',['../plcont_8c.html#a4878bc5ef8877706d1164d6f2f8ac563',1,'plcont.c']]],
  ['redraw',['Redraw',['../plframe_8c.html#a9a9ffa41baf974d1c1e83b209c3f8055',1,'Redraw(Tcl_Interp *, PlFrame *, int, const char **):&#160;plframe.c'],['../plframe_8c.html#ad3d94eeb0371fdaee4998f44ccd75546',1,'Redraw(Tcl_Interp *PL_UNUSED(interp), register PlFrame *plFramePtr, int PL_UNUSED(argc), const char **PL_UNUSED(argv)):&#160;plframe.c'],['../plplotter_8c.html#aa0a104ee99eb61ac8686aa2b6bdd5365',1,'Redraw(Tcl_Interp *, PlPlotter *, int, CONST char **):&#160;plplotter.c'],['../plplotter_8c.html#ab113e3262010abac6a2bd39e5eec8498',1,'Redraw(Tcl_Interp *PL_UNUSED(interp), register PlPlotter *plPlotterPtr, int PL_UNUSED(argc), CONST char **PL_UNUSED(argv)):&#160;plplotter.c']]],
  ['release_5fjava_5farray_5f1d_5fplflt',['release_java_array_1d_PLFLT',['../plplotjavacJAVA__wrap_8c.html#a89b4eadb0c84343053f7ba76def02205',1,'plplotjavacJAVA_wrap.c']]],
  ['remove_5fcharacters',['remove_characters',['../pllegend_8c.html#aaf7b1464be4a506ab53cd4ac569a4124',1,'pllegend.c']]],
  ['removeframe',['RemoveFrame',['../classwxPLplotApp.html#a59ca5aa5eef0185b44214748ccb09b4e',1,'wxPLplotApp']]],
  ['renewplot',['RenewPlot',['../classwxPLplotwindow.html#a2d831cf53e7b6d3b9e622ba90ec59b51',1,'wxPLplotwindow::RenewPlot()'],['../classwxPLplotstream.html#a8a0a794257a11475b2101d67c09807a7',1,'wxPLplotstream::RenewPlot()']]],
  ['replot',['replot',['../classplstream.html#a2c5b31d08823adc08013731a3e700d66',1,'plstream::replot()'],['../classplplot_1_1core_1_1PLStream.html#acb6bdaadb35eb7b522da1603d2e10240',1,'plplot.core.PLStream.replot()']]],
  ['report',['report',['../plframe_8c.html#a63a68632c1682d7ae2343cd6f6784623',1,'report(Tcl_Interp *, PlFrame *, int, const char **):&#160;plframe.c'],['../plframe_8c.html#acb0c89e8571d17240740df533902e7da',1,'report(Tcl_Interp *interp, register PlFrame *plFramePtr, int argc, const char **argv):&#160;plframe.c'],['../plplotter_8c.html#ad428684662256533baa83ca67df1e154',1,'report(Tcl_Interp *, PlPlotter *, int, CONST char **):&#160;plplotter.c'],['../plplotter_8c.html#a7863110487c12b1960642886392f8ddc',1,'report(Tcl_Interp *interp, register PlPlotter *plPlotterPtr, int argc, CONST char **argv):&#160;plplotter.c']]],
  ['resetopts',['ResetOpts',['../classplstream.html#afedc5ae79894b5eb0a61009b5abe2a48',1,'plstream::ResetOpts()'],['../classplplot_1_1core_1_1PLStream.html#ac39e41ee297ba3564b510f74bbf90334',1,'plplot.core.PLStream.ResetOpts()']]],
  ['restorewrite2bufferpixmap',['RestoreWrite2BufferPixmap',['../plimage_8c.html#aee157a1ce47c74660e9598e55a354f56',1,'RestoreWrite2BufferPixmap():&#160;plimage.c'],['../plplotP_8h.html#a429babb5efcabc2bba8944f399fe8866',1,'RestoreWrite2BufferPixmap(void):&#160;plimage.c']]],
  ['rgbhls',['rgbhls',['../classplstream.html#ab20d34ab36c257ca5358218e3000fb8f',1,'plstream::rgbhls()'],['../classplplot_1_1core_1_1PLStream.html#afb7e2f8d9a1d008814a2c2ded3082f52',1,'plplot.core.PLStream.rgbhls()']]],
  ['rise_5fspan_5ftag',['rise_span_tag',['../cairo_8c.html#ab7b09dcaf0bea43547a1d1e8f031628c',1,'cairo.c']]],
  ['rotate_5fcairo_5fsurface',['rotate_cairo_surface',['../cairo_8c.html#a6d4a596076eff5d4d18f6dc79a29fcf5',1,'cairo.c']]]
];

==> plplot-5.11.1.tar.gz: plplot-5.11.1/doc/doxygen/html/search/functions_72.js <==
var searchData=
[
  ['rand',['Rand',['../classRand.html#af6a29a331de2da43b41d3c0c978d3e8d',1,'Rand::Rand()'],['../classRand.html#a067a27409dc17fa6cb22f7e2660f4820',1,'Rand::Rand(unsigned int seed)']]],
  ['randd',['randd',['../classplstream.html#a548b5563e4a23301ca3ea443669d265e',1,'plstream::randd()'],['../classplplot_1_1core_1_1PLStream.html#af99be78ac0c125a40919934c4454316e',1,'plplot.core.PLStream.randd()']]],
  ['rd_5fcommand',['rd_command',['../plbuf_8c.html#afe25464ef6eee65400e6cc414e1a8bef',1,'plbuf.c']]],
  ['rd_5fdata',['rd_data',['../plbuf_8c.html#a242010916ecbf0311b25cb53dd279131',1,'plbuf.c']]],
  ['rd_5fdata_5fno_5fcopy',['rd_data_no_copy',['../plbuf_8c.html#a69e3c6f1b472a4be33d88f73d270cbea',1,'plbuf.c']]],
  ['rdbuf_5fbop',['rdbuf_bop',['../plbuf_8c.html#aad64e647b7f7b3af09f3c62842c4f7c8',1,'plbuf.c']]],
  ['rdbuf_5fclip',['rdbuf_clip',['../plbuf_8c.html#a03098c55de5a88d538fb8da01d6172a7',1,'plbuf.c']]],
  ['rdbuf_5fdi',['rdbuf_di',['../plbuf_8c.html#a438ab9b1261eaecaa968f895d4569ffb',1,'plbuf.c']]],
  ['rdbuf_5feop',['rdbuf_eop',['../plbuf_8c.html#a209868297bfb200c84cbfe90ba08f0e0',1,'rdbuf_eop(PLStream *pls):&#160;plbuf.c'],['../plbuf_8c.html#ad7ca15074bcfb34b7be34e84f2ef4c9a',1,'rdbuf_eop(PLStream *PL_UNUSED(pls)):&#160;plbuf.c']]],
  ['rdbuf_5fesc',['rdbuf_esc',['../plbuf_8c.html#ae88980d2f7d522656c5950ddd56196dd',1,'plbuf.c']]],
  ['rdbuf_5ffill',['rdbuf_fill',['../plbuf_8c.html#aad07e02f2e79a2c170853e8aa4e6b2f9',1,'plbuf.c']]],
  ['rdbuf_5fimage',['rdbuf_image',['../plbuf_8c.html#aea9f032aa713660a5dc4c9977eaa61dd',1,'plbuf.c']]],
  ['rdbuf_5finit',['rdbuf_init',['../plbuf_8c.html#a8db7bde63185bde9dc11e067032d72ca',1,'rdbuf_init(PLStream *pls):&#160;plbuf.c'],['../plbuf_8c.html#ada55e60d5d9707c8b9422473cb15b370',1,'rdbuf_init(PLStream *PL_UNUSED(pls)):&#160;plbuf.c']]],
  ['rdbuf_5fline',['rdbuf_line',['../plbuf_8c.html#a7bec22c9791616b92153645c10edbc36',1,'plbuf.c']]],
  ['rdbuf_5fpolyline',['rdbuf_polyline',['../plbuf_8c.html#a5cc6b30bbe75730cde65b3a2ba00b084',1,'plbuf.c']]],
  ['rdbuf_5fsetsub',['rdbuf_setsub',['../plbuf_8c.html#ad1f778ddc28bcfe4d0e4c6745c81c068',1,'plbuf.c']]],
  ['rdbuf_5fssub',['rdbuf_ssub',['../plbuf_8c.html#a95949f6bffdb4d28fda6fe00691dca8d',1,'plbuf.c']]],
  ['rdbuf_5fstate',['rdbuf_state',['../plbuf_8c.html#ad9ba8fe84be30902c7d521c076a91456',1,'plbuf.c']]],
  ['rdbuf_5fswin',['rdbuf_swin',['../plbuf_8c.html#a2bc6f17b2d907b6785d6c898b45bb064',1,'plbuf.c']]],
  ['rdbuf_5ftext',['rdbuf_text',['../plbuf_8c.html#afa641052a2e12eb594108a56d6eaa710',1,'plbuf.c']]],
  ['rdbuf_5ftext_5funicode',['rdbuf_text_unicode',['../plbuf_8c.html#a6e3e586984481314f86de46295eea6f7',1,'plbuf.c']]],
  ['read_5fdouble_5fmatrix',['read_double_Matrix',['../plplotluacLUA__wrap_8c.html#a03fbc9a75a0be1fa43da9accc215aab2',1,'plplotluacLUA_wrap.c']]],
  ['read_5fentry',['read_entry',['../plmetafile_8c.html#adf426da07e96b874066a32a6731d4adc',1,'plmetafile.c']]],
  ['read_5fescape',['read_escape',['../plmetafile_8c.html#a54f820c307a156f37b7bc44980a88303',1,'plmetafile.c']]],
  ['read_5fheader',['read_header',['../plmetafile_8c.html#a641e319c9f89bbb2df2a1cf09993efec',1,'plmetafile.c']]],
  ['read_5fline',['read_line',['../plctrl_8c.html#a5e4545bc3f40c3e8ad92cdb1ae7e7d46',1,'read_line(char *buffer, int length, FILE *fp):&#160;plctrl.c'],['../plmetafile_8c.html#a54f4fd08b41b3cba674c615bdf9aa3c4',1,'read_line(PDFstrm *plm, PLmDev *dev, PLStream *pls):&#160;plmetafile.c']]],
  ['read_5flineto',['read_lineto',['../plmetafile_8c.html#a7c003091900bc8d454918c694f54c40c',1,'plmetafile.c']]],
  ['read_5fmetafile_5fheader',['read_metafile_header',['../plmetafile_8c.html#a4c75feec4cafc87cdf2a7aa21212ed8d',1,'plmetafile.c']]],
  ['read_5fplot_5fcommands',['read_plot_commands',['../plmetafile_8c.html#a558d09544279e054257b4134598aa30b',1,'plmetafile.c']]],
  ['read_5fpolyline',['read_polyline',['../plmetafile_8c.html#a1b91bcc694ad3aa1ef5d32ab9ac20bc5',1,'plmetafile.c']]],
  ['read_5fstate',['read_state',['../plmetafile_8c.html#a021a50d7526ab4586aa39167c9c0f998',1,'plmetafile.c']]],
  ['read_5fstring',['read_string',['../plmetafile_8c.html#a25103aa335aa2c95f4f5fd2a4127cf14',1,'plmetafile.c']]],
  ['readdata',['ReadData',['../plframe_8c.html#aa66a237bb52c6ba116dc6f27cf390fcf',1,'ReadData(ClientData, int):&#160;plframe.c'],['../plplotter_8c.html#aa66a237bb52c6ba116dc6f27cf390fcf',1,'ReadData(ClientData, int):&#160;plplotter.c']]],
  ['readdir',['readdir',['../dirent__msvc_8h.html#aff48ec2514bda89769c968c66db181f3',1,'dirent_msvc.h']]],
  ['realloc_5fline',['realloc_line',['../plcont_8c.html#a4878bc5ef8877706d1164d6f2f8ac563',1,'plcont.c']]],
  ['rebaselon',['rebaselon',['../plmap_8c.html#adef85394eadb22c0e62e2020daff8aa3',1,'plmap.c']]],
  ['redraw',['Redraw',['../plframe_8c.html#a9a9ffa41baf974d1c1e83b209c3f8055',1,'Redraw(Tcl_Interp *, PlFrame *, int, const char **):&#160;plframe.c'],['../plframe_8c.html#ad3d94eeb0371fdaee4998f44ccd75546',1,'Redraw(Tcl_Interp *PL_UNUSED(interp), register PlFrame *plFramePtr, int PL_UNUSED(argc), const char **PL_UNUSED(argv)):&#160;plframe.c'],['../plplotter_8c.html#aa0a104ee99eb61ac8686aa2b6bdd5365',1,'Redraw(Tcl_Interp *, PlPlotter *, int, CONST char **):&#160;plplotter.c'],['../plplotter_8c.html#ab113e3262010abac6a2bd39e5eec8498',1,'Redraw(Tcl_Interp *PL_UNUSED(interp), register PlPlotter *plPlotterPtr, int PL_UNUSED(argc), CONST char **PL_UNUSED(argv)):&#160;plplotter.c']]],
  ['release',['release',['../classPLNamedMutex.html#abd9c2b7ddb23a6335e8a6a91b0d3da92',1,'PLNamedMutex']]],
  ['release_5fjava_5farray_5f1d_5fplflt',['release_java_array_1d_PLFLT',['../plplotjavacJAVA__wrap_8c.html#a89b4eadb0c84343053f7ba76def02205',1,'plplotjavacJAVA_wrap.c']]],
  ['remove_5fcharacters',['remove_characters',['../pllegend_8c.html#aaf7b1464be4a506ab53cd4ac569a4124',1,'pllegend.c']]],
  ['renewplot',['RenewPlot',['../classwxPLplotstream.html#a8a0a794257a11475b2101d67c09807a7',1,'wxPLplotstream::RenewPlot()'],['../classwxPLplotwindow.html#a0f746b49cc3f84810c303129910bfd5f',1,'wxPLplotwindow::RenewPlot()']]],
  ['replot',['replot',['../classplstream.html#a2c5b31d08823adc08013731a3e700d66',1,'plstream::replot()'],['../classplplot_1_1core_1_1PLStream.html#acb6bdaadb35eb7b522da1603d2e10240',1,'plplot.core.PLStream.replot()']]],
  ['report',['report',['../plframe_8c.html#a63a68632c1682d7ae2343cd6f6784623',1,'report(Tcl_Interp *, PlFrame *, int, const char **):&#160;plframe.c'],['../plframe_8c.html#acb0c89e8571d17240740df533902e7da',1,'report(Tcl_Interp *interp, register PlFrame *plFramePtr, int argc, const char **argv):&#160;plframe.c'],['../plplotter_8c.html#ad428684662256533baa83ca67df1e154',1,'report(Tcl_Interp *, PlPlotter *, int, CONST char **):&#160;plplotter.c'],['../plplotter_8c.html#a7863110487c12b1960642886392f8ddc',1,'report(Tcl_Interp *interp, register PlPlotter *plPlotterPtr, int argc, CONST char **argv):&#160;plplotter.c']]],
  ['resetopts',['ResetOpts',['../classplstream.html#afedc5ae79894b5eb0a61009b5abe2a48',1,'plstream::ResetOpts()'],['../classplplot_1_1core_1_1PLStream.html#ac39e41ee297ba3564b510f74bbf90334',1,'plplot.core.PLStream.ResetOpts()']]],
  ['restorewrite2bufferpixmap',['RestoreWrite2BufferPixmap',['../plimage_8c.html#aee157a1ce47c74660e9598e55a354f56',1,'RestoreWrite2BufferPixmap():&#160;plimage.c'],['../plplotP_8h.html#a429babb5efcabc2bba8944f399fe8866',1,'RestoreWrite2BufferPixmap(void):&#160;plimage.c']]],
  ['rgbhls',['rgbhls',['../classplstream.html#ab20d34ab36c257ca5358218e3000fb8f',1,'plstream::rgbhls()'],['../classplplot_1_1core_1_1PLStream.html#afb7e2f8d9a1d008814a2c2ded3082f52',1,'plplot.core.PLStream.rgbhls()']]],
  ['rise_5fspan_5ftag',['rise_span_tag',['../cairo_8c.html#ab7b09dcaf0bea43547a1d1e8f031628c',1,'cairo.c']]],
  ['rotate_5fcairo_5fsurface',['rotate_cairo_surface',['../cairo_8c.html#a6d4a596076eff5d4d18f6dc79a29fcf5',1,'cairo.c']]]
];
